#ifndef NT2_INCLUDE_CONSTANTS_MONEO_6_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MONEO_6_HPP_INCLUDED

#include <nt2/constant/include/constants/moneo_6.hpp>

#endif
